==> notolog-0.9.1b3.tar.gz: notolog-0.9.1b3/notolog/lexemes/de/toolbar.py <==
# German lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Neues Dokument",
    "actions_accessible_name_new_document": "Neues Dokument",
    "actions_label_open": "Öffnen",
    "actions_accessible_name_open": "Dokument öffnen",
    "actions_label_save": "Speichern",
    "actions_accessible_name_save": "Dokument speichern",
    "actions_label_save_as": "Speichern unter",
    "actions_accessible_name_save_as": "Kopie des Dokuments speichern",
    "actions_label_sync": "Synchronisieren",
    "actions_accessible_name_sync": "Dokument mit externem Speicher synchronisieren",
    "actions_label_edit": "Bearbeiten",
    "actions_accessible_name_edit": "Datei bearbeiten",
    "actions_label_source": "Quelle",
    "actions_accessible_name_source": "Quellcode",
    "actions_label_encrypt": "Verschlüsseln",
    "actions_accessible_name_encrypt": "Datei verschlüsseln",
    "actions_label_decrypt": "Entschlüsseln",
    "actions_accessible_name_decrypt": "Datei entschlüsseln",
    "actions_label_bold": "Fett",
    "actions_accessible_name_bold": "Text fett formatieren",
    "actions_label_italic": "Kursiv",
    "actions_accessible_name_italic": "Text kursiv formatieren",
    "actions_label_underline": "Unterstreichen",
    "actions_accessible_name_underline": "Text unterstreichen",
    "actions_label_strikethrough": "Durchstreichen",
    "actions_accessible_name_strikethrough": "Text durchstreichen",
    "actions_label_blockquote": "Blockzitat",
    "actions_accessible_name_blockquote": "Text als Blockzitat formatieren",
    "actions_label_color_picker": "Farbwähler",
    "actions_accessible_name_color_picker": "Textfarbe wählen",
    "actions_label_ai_assistant": "KI-Assistent",
    "actions_accessible_name_ai_assistant": "KI-Assistent ausführen",
    "actions_label_about": "Über",
    "actions_accessible_name_about": "Über die App",
    "actions_label_exit": "Beenden",
    "actions_accessible_name_exit": "App beenden",
    "actions_label_settings": "Einstellungen",
    "actions_accessible_name_settings": "App-Einstellungen",

    "search_input_label": "Suchen",
    "search_input_placeholder_text": "Text im Dokument",
    "search_input_accessible_description": "Sucheingabefeld",
    "search_buttons_label_clear": "Suche löschen",
    "search_buttons_accessible_name_clear": "Sucheingabefeld löschen",
    "search_buttons_label_prev": "Vorherige Suche",
    "search_buttons_accessible_name_prev": "Vorheriges Suchergebnis",
    "search_buttons_label_next": "Nächste Suche",
    "search_buttons_accessible_name_next": "Nächstes Suchergebnis",
    "search_case_sensitive": "Groß-/Kleinschreibung beachten",
    "search_match_case_tooltip": "Suche unter Berücksichtigung der Groß-/Kleinschreibung",
}

==> notolog-1.1.5.tar.gz: notolog-1.1.5/notolog/lexemes/de/toolbar.py <==
# German lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Neues Dokument",
    "actions_accessible_name_new_document": "Neues Dokument",
    "actions_label_open": "Öffnen",
    "actions_accessible_name_open": "Dokument öffnen",
    "actions_label_save": "Speichern",
    "actions_accessible_name_save": "Dokument speichern",
    "actions_label_save_as": "Speichern unter",
    "actions_accessible_name_save_as": "Kopie des Dokuments speichern",
    "actions_label_sync": "Synchronisieren",
    "actions_accessible_name_sync": "Dokument mit externem Speicher synchronisieren",
    "actions_label_edit": "Bearbeiten",
    "actions_accessible_name_edit": "Datei bearbeiten",
    "actions_label_source": "Quelle",
    "actions_accessible_name_source": "Quellcode",
    "actions_label_encrypt": "Verschlüsseln",
    "actions_accessible_name_encrypt": "Datei verschlüsseln",
    "actions_label_decrypt": "Entschlüsseln",
    "actions_accessible_name_decrypt": "Datei entschlüsseln",
    "actions_label_bold": "Fett",
    "actions_accessible_name_bold": "Text fett formatieren",
    "actions_label_italic": "Kursiv",
    "actions_accessible_name_italic": "Text kursiv formatieren",
    "actions_label_underline": "Unterstreichen",
    "actions_accessible_name_underline": "Text unterstreichen",
    "actions_label_strikethrough": "Durchstreichen",
    "actions_accessible_name_strikethrough": "Text durchstreichen",
    "actions_label_blockquote": "Blockzitat",
    "actions_accessible_name_blockquote": "Text als Blockzitat formatieren",
    "actions_label_color_picker": "Farbwähler",
    "actions_accessible_name_color_picker": "Textfarbe wählen",
    "actions_label_ai_assistant": "KI-Assistent",
    "actions_accessible_name_ai_assistant": "KI-Assistent ausführen",
    "actions_label_about": "Über",
    "actions_accessible_name_about": "Über die App",
    "actions_label_exit": "Beenden",
    "actions_accessible_name_exit": "App beenden",
    "actions_label_settings": "Einstellungen",
    "actions_accessible_name_settings": "App-Einstellungen",

    "search_input_label": "Suchen",
    "search_input_placeholder_text": "Text im Dokument suchen",
    "search_input_accessible_description": "Sucheingabefeld",
    "search_buttons_label_clear": "Suche löschen",
    "search_buttons_accessible_name_clear": "Sucheingabefeld löschen",
    "search_buttons_label_prev": "Vorherige Suche",
    "search_buttons_accessible_name_prev": "Vorheriges Suchergebnis",
    "search_buttons_label_next": "Nächste Suche",
    "search_buttons_accessible_name_next": "Nächstes Suchergebnis",
    "search_case_sensitive_accessible_name": "Groß-/Kleinschreibung beachten",
    "search_case_sensitive_tooltip": "Suche unter Berücksichtigung der Groß-/Kleinschreibung",
}
